#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-change-type-signature-plugin
version:              2.3.0.0
visibility:           public
id:
    hls-change-type-signature-plugin-2.3.0.0-1IgdbCJ9V3NIgL8wxFCx03

key:
    hls-change-type-signature-plugin-2.3.0.0-1IgdbCJ9V3NIgL8wxFCx03

license:              Apache-2.0
maintainer:           nicksuchecki@gmail.com
author:               Nick Suchecki
synopsis:             Change a declarations type signature with a Code Action
description:
    Please see the README on GitHub at <https://github.com/haskell/plugins/hls-change-type-signature-plugin/README.md>

category:             Development
abi:                  67d6ffc2dbfb691f4697ded9618f2e36
exposed:              True
exposed-modules:      Ide.Plugin.ChangeTypeSignature
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-change-type-signature-plugin-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-change-type-signature-plugin-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-change-type-signature-plugin-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-change-type-signature-plugin
hs-libraries:
    HShls-change-type-signature-plugin-2.3.0.0-1IgdbCJ9V3NIgL8wxFCx03

depends:
    base-4.18.2.1 containers-0.6.7
    ghcide-2.3.0.0-18sa3skFOT1HznOGP4KL4J
    hls-plugin-api-2.3.0.0-6FbyogaZUzQnICn9LIAaM
    lsp-types-2.0.2.0-FxqOKdDzvom3LxZERPn3Y4
    regex-tdfa-1.3.2.5-K3WM9QKkG8i6YZ8c6M2glc
    syb-0.7.4-CWkOfF6Y0mt62kPybHOEB1 text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.21-5Z67IC6H036CG8YRUzTmvt

haddock-interfaces:
    /usr/share/doc/haskell-hls-change-type-signature-plugin/html/hls-change-type-signature-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-change-type-signature-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

